====================================================
**cofe** --- Cluster-Orbit Function Expansion Module
====================================================

This module classes and functions to define, train, and
test cluster expansions.

.. toctree::
   :maxdepth: 2

   clusterspace
   space
   clusterexpansion
   wrangling
   extern.ewald
